==> nextcloud-app-mail-0.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correo electrónico",
    "Error while loading the accounts." : "Error al cargar las cuentas.",
    "Error while loading the selected account." : "Error al cargar la cuenta seleccionada.",
    "Can not load this folder." : "No se puede cargar esta carpeta.",
    "Loading {folder}" : "Cargando {folder}",
    "Searching for {query}" : "Buscando por (consulta)",
    "Error while deleting message." : "Error al eliminar el mensaje.",
    "Forwarded message" : "Mensaje reenviado",
    "Choose a folder to store the attachment in" : "Escoja una carpeta para guardar el adjunto",
    "Attachments saved to Files." : "Archivos adjuntos guardados en Archivos.",
    "Attachment saved to Files." : "Archivo adjunto guardado en Archivos.",
    "Error while saving attachments to Files." : "Error al guardar archivos adjuntos en Archivos.",
    "Error while saving attachment to Files." : "Error al guardar archivo adjunto en Archivos.",
    "Message flag could not be set." : "No se pudo marcar el mensaje. ",
    "Could not move message." : "No se pudo mover el mensaje",
    "Invalid account" : "Cuenta inválida",
    "Invalid folder" : "Carpeta inválida",
    "Error while creating the account: " : "Error al crear la cuenta:",
    "Unknown error" : "Error desconocido",
    "All inboxes" : "Todas las bandejas de entrada",
    "you" : "usted",
    "Send message to {email}" : "Enviar mensaje a {email}",
    "Could not load {tag}{name}{endtag}" : "No se pudo cargar {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "No se pudo carcar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Hubo un problema cargando {tag}{name}{endtag}",
    "We couldn’t load your message" : "No podemos cargar tu mensaje",
    "Unable to load the desired message" : "No se pudo cargar el mensaje solicitado",
    "There was a problem loading the message" : "Ha habido un problema al cargar el mensaje",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Show all folders" : "Mostrar todas las carpetas",
    "Collapse folders" : "Plegar carpetas",
    "Error while deleting account." : "Error al eliminar la cuenta.",
    "Choose a file to add as attachment" : "Escoja un archivo para adjuntar",
    "An error occurred while uploading {fname}" : "Ha ocurrido un error al cargar {fname}",
    "Reply" : "Responder",
    "Send" : "Enviar",
    "Sending …" : "Enviando ...",
    "Message sent!" : "¡Mensaje enviado!",
    "Server error" : "Error en servidor",
    "An unknown error occurred" : "Un error desconocido ha ocurrido",
    "Opening HTML drafts is not supported yet." : "La apertura de borradores HTML aun no está soportada.",
    "Draft saved!" : "¡Borrador guardado!",
    "No writable calendars found" : "No se han encontrado calendarios con permiso de escritura",
    "Error while importing the calendar event" : "Error al importar el evento de calendario",
    "Error while downloading calendar event" : "Error al descargar el evento de calendario",
    "Error while loading messages." : "Error al cargar los mensajes.",
    "Setting up your account" : "Configurando tu cuenta",
    "Inbox" : "Recibidos",
    "Sent" : "Enviado",
    "Drafts" : "Borradores",
    "Archive" : "Archivados",
    "Trash" : "Papelera",
    "Junk" : "Basura",
    "All" : "Todos",
    "Favorites" : "Favoritos",
    "Creating account failed: " : "No se pudo crear la cuenta:",
    "Auto detect failed. Please use manual mode." : "La autodetección falló. Use el modo manual.",
    "Delete permanently" : "Eliminar permanentemente",
    "& others" : "y otros",
    "Error loading message" : "Error al cargar el mensaje",
    "Settings" : "Ajustes",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haga click aqui si no es redireccionado automaticamente en los proximos segundos.",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "El enlace conduce a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no desea visitar esa página, puede volver a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s",
    "Delete account" : "Eliminar cuenta",
    "Try again" : "Vuelve a intentarlo",
    "New message" : "Nuevo mensaje",
    "Account Settings" : "Ajustes de la Cuenta",
    "Aliases" : "Alias",
    "Mail address" : "Dirección de correo electrónico",
    "Display Name" : "Nombre a mostrar",
    "Save" : "Guardar",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de Correo con estos rápidos atajos de teclado.",
    "Compose new message" : "Crear nuevo mensaje",
    "Newer message" : "Mensaje más moderno",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Marcar/desmarcar con estrella",
    "Toggle unread" : "Marcar/desmarcar como leído",
    "Delete" : "Eliminar",
    "Search" : "Buscar",
    "Refresh" : "Recargar",
    "Connect your mail account" : "Conecte su cuenta de correo electrónico",
    "Name" : "Nombre",
    "Mail Address" : "Dirección de correo electrónico",
    "Password" : "Contraseña",
    "Manual configuration" : "Configuración manual",
    "IMAP Host" : "Servidor IMAP",
    "IMAP security" : "Seguridad IMAP",
    "None" : "Ninguno",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servidor SMTP",
    "SMTP security" : "Seguridad SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Connect" : "Conectar",
    "from" : "desde",
    "to" : "para",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Asunto",
    "Save all to Files" : "Guardar todo en Archivos",
    "Add mail account" : "Añadir cuenta de correo electrónico",
    "No search results for" : "Ningún resultado para la búsqueda de",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad.",
    "Show images from this sender" : "Mostrar imágenes de este remitente",
    "Forward" : "Reenviar",
    "Add attachment" : "Añadir adjunto",
    "Add from Files" : "Añadir desde Archivos",
    "Import into calendar" : "Importar dentro del calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar en Archivos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correo electrónico",
    "Error while loading the accounts." : "Error al cargar las cuentas.",
    "Error while loading the selected account." : "Error al cargar la cuenta seleccionada.",
    "Can not load this folder." : "No se puede cargar esta carpeta.",
    "Loading {folder}" : "Cargando {folder}",
    "Searching for {query}" : "Buscando por (consulta)",
    "Error while deleting message." : "Error al eliminar el mensaje.",
    "Forwarded message" : "Mensaje reenviado",
    "Choose a folder to store the attachment in" : "Escoja una carpeta para guardar el adjunto",
    "Attachments saved to Files." : "Archivos adjuntos guardados en Archivos.",
    "Attachment saved to Files." : "Archivo adjunto guardado en Archivos.",
    "Error while saving attachments to Files." : "Error al guardar archivos adjuntos en Archivos.",
    "Error while saving attachment to Files." : "Error al guardar archivo adjunto en Archivos.",
    "Message flag could not be set." : "No se pudo marcar el mensaje. ",
    "Could not move message." : "No se pudo mover el mensaje",
    "Invalid account" : "Cuenta inválida",
    "Invalid folder" : "Carpeta inválida",
    "Error while creating the account: " : "Error al crear la cuenta:",
    "Unknown error" : "Error desconocido",
    "All inboxes" : "Todas las bandejas de entrada",
    "you" : "usted",
    "Send message to {email}" : "Enviar mensaje a {email}",
    "Could not load {tag}{name}{endtag}" : "No se pudo cargar {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "No se pudo carcar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Hubo un problema cargando {tag}{name}{endtag}",
    "We couldn’t load your message" : "No podemos cargar tu mensaje",
    "Unable to load the desired message" : "No se pudo cargar el mensaje solicitado",
    "There was a problem loading the message" : "Ha habido un problema al cargar el mensaje",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos\nde {from}"],
    "Nextcloud Mail" : "Correo de Nextcloud",
    "Show all folders" : "Mostrar todas las carpetas",
    "Collapse folders" : "Plegar carpetas",
    "Error while deleting account." : "Error al eliminar la cuenta.",
    "Choose a file to add as attachment" : "Escoja un archivo para adjuntar",
    "An error occurred while uploading {fname}" : "Ha ocurrido un error al cargar {fname}",
    "Reply" : "Responder",
    "Send" : "Enviar",
    "Sending …" : "Enviando ...",
    "Message sent!" : "¡Mensaje enviado!",
    "Server error" : "Error en servidor",
    "An unknown error occurred" : "Un error desconocido ha ocurrido",
    "Opening HTML drafts is not supported yet." : "La apertura de borradores HTML aun no está soportada.",
    "Draft saved!" : "¡Borrador guardado!",
    "No writable calendars found" : "No se han encontrado calendarios con permiso de escritura",
    "Error while importing the calendar event" : "Error al importar el evento de calendario",
    "Error while downloading calendar event" : "Error al descargar el evento de calendario",
    "Error while loading messages." : "Error al cargar los mensajes.",
    "Error while refreshing messages." : "Error al recargar los mensajes.",
    "Setting up your account" : "Configurando tu cuenta",
    "Inbox" : "Recibidos",
    "Sent" : "Enviado",
    "Drafts" : "Borradores",
    "Archive" : "Archivados",
    "Trash" : "Papelera",
    "Junk" : "Basura",
    "All" : "Todos",
    "Favorites" : "Favoritos",
    "Creating account failed: " : "No se pudo crear la cuenta:",
    "Auto detect failed. Please use manual mode." : "La autodetección falló. Use el modo manual.",
    "Delete permanently" : "Eliminar permanentemente",
    "& others" : "y otros",
    "Error loading message" : "Error al cargar el mensaje",
    "Settings" : "Ajustes",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haga click aqui si no es redireccionado automaticamente en los proximos segundos.",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "El enlace conduce a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no desea visitar esa página, puede volver a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s",
    "Delete account" : "Eliminar cuenta",
    "Try again" : "Vuelve a intentarlo",
    "New message" : "Nuevo mensaje",
    "Account Settings" : "Ajustes de la Cuenta",
    "Aliases" : "Alias",
    "Mail address" : "Dirección de correo electrónico",
    "Display Name" : "Nombre a mostrar",
    "Save" : "Guardar",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de Correo con estos rápidos atajos de teclado.",
    "Compose new message" : "Crear nuevo mensaje",
    "Newer message" : "Mensaje más moderno",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Marcar/desmarcar con estrella",
    "Toggle unread" : "Marcar/desmarcar como leído",
    "Delete" : "Eliminar",
    "Search" : "Buscar",
    "Refresh" : "Recargar",
    "Connect your mail account" : "Conecte su cuenta de correo electrónico",
    "Name" : "Nombre",
    "Mail Address" : "Dirección de correo electrónico",
    "Password" : "Contraseña",
    "Manual configuration" : "Configuración manual",
    "IMAP Host" : "Servidor IMAP",
    "IMAP security" : "Seguridad IMAP",
    "None" : "Ninguno",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servidor SMTP",
    "SMTP security" : "Seguridad SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Connect" : "Conectar",
    "from" : "desde",
    "to" : "para",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Asunto",
    "Save all to Files" : "Guardar todo en Archivos",
    "Add mail account" : "Añadir cuenta de correo electrónico",
    "No search results for" : "Ningún resultado para la búsqueda de",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad.",
    "Show images from this sender" : "Mostrar imágenes de este remitente",
    "Forward" : "Reenviar",
    "Add attachment" : "Añadir adjunto",
    "Add from Files" : "Añadir desde Archivos",
    "Import into calendar" : "Importar dentro del calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar en Archivos"
},
"nplurals=2; plural=(n != 1);");
